@@ -12,14 +12,16 @@ test_that("weather alerts works", {
   expect_error(weather(poi = poi, url_only = "not_a_bool"), "'url_only' must be a 'boolean' value.")
 
   # Test with API response mock
-  with_mock(
-    "hereR:::.async_request" = function(url, rps) {
+  with_mocked_bindings(
+    .async_request = function(url, rps) {
       hereR:::mock$weather_alerts_response
     },
-    weather_alerts <- weather(poi = poi, product = "alerts"),
+    {
+      weather_alerts <- weather(poi = poi, product = "alerts")
 
-    # Tests
-    expect_equal(any(sf::st_geometry_type(weather_alerts) != "POINT"), FALSE),
-    expect_equal(nrow(weather_alerts), nrow(poi))
+      # Tests
+      expect_equal(any(sf::st_geometry_type(weather_alerts) != "POINT"), FALSE)
+      expect_equal(nrow(weather_alerts), nrow(poi))
+    }
   )
 })
